import { StepMapping } from '../../../field-mapping/FieldMapping';
import { IdentityManagementType } from '../../../constants/wizard.constants';

export enum IdentityField {
    BIND_DN = 'bindDN',
    BIND_PW = 'bindPW',
    CLIENT_ID = 'clientId',
    CLIENT_SECRET = 'clientSecret',
    ENDPOINT_IP = 'endpointIp',
    ENDPOINT_PORT = 'endpointPort',
    GROUP_SEARCH_BASE_DN = 'groupSearchBaseDN',
    GROUP_SEARCH_FILTER = 'groupSearchFilter',
    GROUP_SEARCH_GROUP_ATTR = 'groupSearchGroupAttr',
    GROUP_SEARCH_NAME_ATTR = 'groupSearchNameAttr',
    GROUP_SEARCH_USER_ATTR = 'groupSearchUserAttr',
    IDENTITY_TYPE = 'identityType',
    IDM_SETTINGS = 'idmSettings',
    ISSUER_URL = 'issuerURL',
    LDAP_ROOT_CA = 'ldapRootCAData',
    OIDC_GROUPS_CLAIM = 'oidcGroupsClaim',
    OIDC_USERNAME_CLAIM = 'oidcUsernameClaim',
    SCOPES = 'scopes',
    TEST_GROUP_NAME = 'testGroupName',
    TEST_USER_NAME = 'testUserName',
    USER_SEARCH_BASE_DN = 'userSearchBaseDN',
    USER_SEARCH_FILTER = 'userSearchFilter',
    USER_SEARCH_USERNAME = 'userSearchUsername',
}

export const IdentityStepMapping: StepMapping = {
    fieldMappings: [
        { name: IdentityField.IDM_SETTINGS, isBoolean: true, defaultValue: false, label: 'ACTIVATE IDENTITY MANAGEMENT SETTINGS' },
        { name: IdentityField.IDENTITY_TYPE, defaultValue: IdentityManagementType.OIDC, label: 'IDENTITY PROVIDER TYPE' },
        { name: IdentityField.ISSUER_URL, label: 'ISSUER URL' },
        { name: IdentityField.CLIENT_ID, label: 'CLIENT ID' },
        { name: IdentityField.CLIENT_SECRET, mask: true, label: 'CLIENT SECRET' },
        { name: IdentityField.SCOPES, label: 'SCOPES' },
        { name: IdentityField.OIDC_USERNAME_CLAIM, label: 'USERNAME CLAIM' },
        { name: IdentityField.OIDC_GROUPS_CLAIM , label: 'GROUPS CLAIM' },
        { name: IdentityField.ENDPOINT_IP, label: 'LDAPS ENDPOINT' },
        { name: IdentityField.ENDPOINT_PORT , label: 'LDAPS ENDPOINT PORT' },
        { name: IdentityField.BIND_DN, label: 'BIND DN (OPTIONAL)' },
        { name: IdentityField.BIND_PW, mask: true, label: 'BIND PASSWORD (OPTIONAL)' },
        { name: IdentityField.USER_SEARCH_BASE_DN, label: 'BASE DN (OPTIONAL)' },
        { name: IdentityField.USER_SEARCH_FILTER, label: 'FILTER' },
        { name: IdentityField.USER_SEARCH_USERNAME, label: 'USERNAME' },
        { name: IdentityField.GROUP_SEARCH_BASE_DN, label: 'BASE DN (OPTIONAL)' },
        { name: IdentityField.GROUP_SEARCH_FILTER, label: 'FILTER' },
        { name: IdentityField.GROUP_SEARCH_NAME_ATTR, label: 'NAME ATTRIBUTE (OPTIONAL)' },
        { name: IdentityField.GROUP_SEARCH_USER_ATTR, label: 'USER ATTRIBUTE (OPTIONAL)' },
        { name: IdentityField.GROUP_SEARCH_GROUP_ATTR, label: 'GROUP ATTRIBUTE (OPTIONAL)' },
        { name: IdentityField.LDAP_ROOT_CA, label: 'ROOT CA (OPTIONAL)' },
        { name: IdentityField.TEST_USER_NAME, label: 'TEST USER NAME (OPTIONAL)' },
        { name: IdentityField.TEST_GROUP_NAME, label: 'TEST GROUP NAME (OPTIONAL)' },
    ]
}
